#define G_LOG_DOMAIN "gpod-library-view"

#include "config.h"

#include "gpod-library-view.h"

#include <gdk/gdk.h>
#include <gtk/gtk.h>
#include <glib/gi18n.h>

/**
 * SECTION:gpod-library-view
 * @title: GpodLibraryView
 * @short_description: A #GtkBox widget for list feeds
 * @include: gpod-library-view.h
 * @see_also: #GpodFeed, #GpodFeedWidget
 *
 * The #GpodLibraryView is an instance #GtkBox, and acts as the primary
 * window/widget for listing feeds in the #GpodWindow<!-- -->'s #GtkStack.
 **/

typedef struct _GpodLibraryViewPrivate
{
    GtkWidget *flow_box;
} GpodLibraryViewPrivate;

struct _GpodLibraryView
{
    GtkBox parent;
};

G_DEFINE_TYPE_WITH_PRIVATE (GpodLibraryView, gpod_library_view, GTK_TYPE_BOX)

static void
add_feed (GpodLibraryView *self)
{
/*
    GpodLibraryViewPrivate *priv = gpod_library_view_get_instance_private (self);
    GtkBuilder *builder = gtk_builder_new ();
    GError *error = NULL;
    GtkWidget *item;
    GtkLabel *title;
    GtkImage *image;

    g_assert (GPOD_IS_LIBRARY_VIEW (self));
    g_assert (GPOD_IS_FEED (feed));
    g_assert (GTK_IS_FLOW_BOX (priv->flow_box));

    if (!gtk_builder_add_from_resource (builder, PACKAGE_RESOURCES "/ui/widgets/library-view-item.ui", &error))
    {
        g_warning ("Unable to add feed to LibraryView: %s", error->message);
        g_error_free (error);
        return;
    }

    item = GTK_WIDGET (g_object_ref (gtk_builder_get_object (builder, "box")));
    title = GTK_LABEL (g_object_ref (gtk_builder_get_object (builder, "title")));
    image = GTK_IMAGE (g_object_ref (gtk_builder_get_object (builder, "image")));

    gtk_label_set_label (title, gpod_feed_get_title (feed));
    //gtk_image_set_from_pixbuf (image, "temp");

    //preview_icon_surface = gdk_cairo_surface_create_from_pixbuf (preview_icon, scale, NULL);
    //gtk_image_set_from_surface (image,

    gtk_flow_box_insert (GTK_FLOW_BOX (priv->flow_box),
                         GTK_WIDGET (item),
                         -1);
*/
    /* Clean-up */
    //g_clear_object (&builder);
}

/*
 * gpod_library_view_finalize:
 * @object: An instance of #GpodLibraryView
 *
 * Does any last minute clean-ups when the class ends.
 */
static void
gpod_library_view_finalize (GObject *object)
{
    G_OBJECT_CLASS (gpod_library_view_parent_class)->finalize(object);
}

/*
 * gpod_library_view_init:
 * @self: An instance of #GpodLibraryView
 *
 * Initializes various aspects of the #GpodLibraryView. Anything the #GpodLibraryView
 * would need before becoming presented should be done here.
 */
static void
gpod_library_view_init (GpodLibraryView *self)
{
    /* Init views/feeds.ui template */
    gtk_widget_init_template (GTK_WIDGET (self));
}

/*
 * gpod_library_view_class_init:
 * @klass: An instance of #GpodLibraryViewClass
 *
 * Initializes the various virtural functions in #GpodLibraryViewClass. In
 * addtition it connects the various #GtkWidgets from the gresource file using
 * gtk_widget_class_set_template_from_resource().
 */
static void
gpod_library_view_class_init (GpodLibraryViewClass *klass)
{
    GObjectClass *object_class = G_OBJECT_CLASS (klass);
    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);

    object_class->finalize = gpod_library_view_finalize;

    gtk_widget_class_set_template_from_resource (widget_class,
                                                 PACKAGE_RESOURCES "/ui/views/library.ui");

    gtk_widget_class_bind_template_child_private (widget_class, GpodLibraryView, flow_box);
}

/**
 * gpod_library_view_new:
 *
 * Creates a new #GpodLibraryView, a custom widget to show all feeds user is
 * subscribed to.
 *
 * ## Usage
 * |[
 * GpodLibraryView *library_view;
 *
 * library_view = gpod_library_view_new ();
 * ]|
 *
 * Returns: #GpodLibraryView
 */
GpodLibraryView *
gpod_library_view_new ()
{
    return g_object_new (GPOD_TYPE_LIBRARY_VIEW,
                         NULL);
}

void
gpod_library_view_add_feed (GpodLibraryView *self)
{
    add_feed (self);
}
